@@ -1,16 +1,26 @@
 import numpy as np
-from .config import DENDRITES_VIDEO, NUCLEATION_VIDEO
-
+from .config import BSE_ONE, BSE_TWO, CELL_ONE, CELL_TWO, DENDRITES_ONE, NUCLEATION_ONE
 
 class Microscope:
 
-    def __init__(self, groundTruthName):
+    SUPPORTED_GROUND_TRUTHS = {
+        "bse_one": BSE_ONE,
+        "bse_two": BSE_TWO,
+        "cell_one": CELL_ONE,
+        "cell_two": CELL_TWO,
+        "dendrites_one": DENDRITES_ONE,
+        "nucleation_one": NUCLEATION_ONE,
+    }
 
-        self.SUPPORTED_GROUND_TRUTHS = {"dendrites": DENDRITES_VIDEO, "nucleation": NUCLEATION_VIDEO}
+    def __init__(self, groundTruthName):
+        if groundTruthName not in self.SUPPORTED_GROUND_TRUTHS:
+            raise ValueError(
+                f"Unsupported groundTruthName: {groundTruthName}. "
+                f"Supported: {list(self.SUPPORTED_GROUND_TRUTHS.keys())}"
+            )
         self.groundTruthVideo = self.SUPPORTED_GROUND_TRUTHS[groundTruthName]
 
     def sample_image(self, yCoords, xCoords, imageShape, frameNumber):
-
         frame = self.groundTruthVideo[frameNumber]
 
         if imageShape[0] > frame.shape[0] or imageShape[1] > frame.shape[1]:
